@@ -2,6 +2,40 @@ using System;
 using System.Runtime.InteropServices;
 
 namespace Evolution {
+	public enum CalMode : int {
+		Invalid = -1,
+		Local = 1 << 0,
+		Remote = 1 << 1,
+		Any= 0x07
+	}
+
+	public enum BackendStatus {
+		Success,
+		RepositoryOffline,
+		PermissionDenied,
+		InvalidRange,
+		ObjectNotFound,
+		InvalidObject,
+		ObjectIdAlreadyExists,
+		AuthenticationFailed,
+		AuthenticationRequired,
+		UnsupportedField,
+		UnsupportedMethod,
+		UnsupportedAuthenticationMethod,
+		TLSNotAvailable,
+		NoSuchCal,
+		UnknownUser,
+		OfflineUnavailable,
+		SearchSizeLimitExceeded,
+		SearchTimeLimitExceeded,
+		InvalidQuery,
+		QueryRefused,
+		CouldNotCancel,
+		OtherError,
+		InvalidServerVersion
+	}
+
+
 	public class CalUtil : GLibUtil {
 /*
 		public static CalRecurrence[] GLibSListToCalRecurrenceArray (IntPtr slist)
